@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide access to chemical element properties
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use Moo;
 use strictures 2;
@@ -84,13 +84,16 @@ sub as_file {
 sub number {
     my ($self, $string) = @_;
     my $n;
+    # looking for a symbol
     if (length $string < 4) {
         $n = $self->symbols->{ ucfirst $string }[0];
     }
+    # looking for an element name
     else {
         for my $symbol (keys %{ $self->symbols }) {
             if (lc $self->symbols->{$symbol}[1] eq lc $string) {
                 $n = $self->symbols->{$symbol}[0];
+                last;
             }
         }
     }
@@ -164,7 +167,7 @@ Chemistry::PeriodicTable - Provide access to chemical element properties
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
